@@ -9,12 +9,12 @@ import shutil
 import fnmatch
 import logging
 
-from jinja2 import Environment, FileSystemLoader
+from jinja2 import Environment, ChoiceLoader, FileSystemLoader
 
 from .helpers import lazy_property
 
 __all__ = ['Folio']
-__version__ = '0.2'
+__version__ = '0.3'
 
 
 class Folio(object):
@@ -46,6 +46,8 @@ class Folio(object):
     default_config = {
         'DEBUG':                                False,
         'TESTING':                              False,
+        'EXTENSIONS':                           [],
+        'JINJA_EXTENSIONS':                     [],
     }
 
     def __init__(self, import_name, source_path='src', build_path='build',
@@ -61,6 +63,7 @@ class Folio(object):
 
         #: Make the configuration dictionary.
         self.config = self._create_config()
+        self.config_initialized = False
 
         #: The destination directory to copy the static content and create the
         #: builded templates.
@@ -142,26 +145,56 @@ class Folio(object):
         return path
 
     def _create_config(self):
-        """Create the configuration dictionary based on the default config."""
+        """Create the configuration dictionary based on the default
+        configuration."""
         new_config = {}
         new_config.update(self.default_config)
         return new_config
 
-    def _create_jinja_loader(self):
+    def init_config(self):
+        """Initialize the configuration."""
+
+        if self.config_initialized:
+            return
+
+        # Register extensions.
+        for extension in self.config.get('EXTENSIONS', []):
+            self.register_extension(extension)
+
+        # Register Jinja extensions.
+        for jinja_extension in self.config.get('JINJA_EXTENSIONS', []):
+            self.env.add_extension(jinja_extension)
+
+        self.config_initialized = True
+
+    @lazy_property
+    def jinja_loader(self):
         """Create a Jinja loader."""
-        return FileSystemLoader(searchpath=self.source_path)
+        return ChoiceLoader([
+            FileSystemLoader(searchpath=self.source_path)
+        ])
 
     def _create_jinja_environment(self, extensions):
         """Create a Jinja environment."""
-        env = Environment(loader=self._create_jinja_loader(),
+        env = Environment(loader=self.jinja_loader,
                           extensions=extensions)
         env.globals.update({
             'config': self.config,
+            'version': __version__,
         })
 
         return env
 
     def add_extension(self, extension):
+        """Add an extension to the registry."""
+        self.config.get('EXTENSIONS', []).append(extension)
+
+        # If the configuration was already initialized, we register the
+        # extension automatically.
+        if self.config_initialized:
+            self.register_extension(extension)
+
+    def register_extension(self, extension):
         """Registers a new extension.
 
         Extensions can be used to add extra functionality to Folio. As they
@@ -186,6 +219,8 @@ class Folio(object):
                 except ImportError:
                     continue
 
+                self.logger.debug("Extension '%s' found." % extension)
+
                 # Consider the module as an extension. Use the first one to
                 # prioritize build-in extensions.
                 extname, extension = extension, module
@@ -223,7 +258,12 @@ class Folio(object):
             extension.register(self)
 
     def build(self):
-        """Build templates to the build directory."""
+        """Build templates to the build directory. It will create the build
+        path if not exists, and build all matched templates."""
+
+        # Initialize the configuration.
+        self.init_config()
+
         # If the build directory does exits, create it.
         if not os.path.exists(self.build_path):
             os.mkdir(self.build_path)
@@ -272,6 +312,11 @@ class Folio(object):
         #: open and process.
         src = os.path.join(self.source_path, template_name)
 
+        # If the template is not in the src directory, it has to be inside a
+        # theme. So we tried to load it from the ChoiceLoader.
+        if not os.path.exists(src):
+            src = self.jinja_loader.get_source(self.env, template_name)[1]
+
         try:
             # Maybe the builder is an instance of class and has a method for
             # translating the template name into the destination name.
@@ -317,7 +362,7 @@ class Folio(object):
             except TypeError:
                 raise TypeError('The pattern is not a string, nor iterable.')
             for item in iterator:
-                self.builders.append((item, builder))
+                self.add_builder(item, builder)
 
     def get_builder(self, template_name):
         """Returns the builder for the given template name or None if there are
@@ -379,7 +424,7 @@ class Folio(object):
             except TypeError:
                 raise TypeError('The pattern is not a string, nor iterable.')
             for item in iterator:
-                self.contexts.append((item, context))
+                self.add_context(item, context)
 
     def get_context(self, template_name):
         """Returns a context for the given template. If more that one context
@@ -392,7 +437,7 @@ class Folio(object):
             proj.add_context('index.html', {'name': 'Juan', 'files': [])
             proj.add_context('index.html', lambda env: {'name': 'Flor'})
             proj.get_context('index.html')
-            # Returns {'name': 'Flor', 'files': [])
+            # Returns {'name': 'Flor', 'files': []}
 
         :param template_name: The template name to retrieve the context.
         """
