@@ -1,6 +1,18 @@
 # -*- coding: utf-8 -*-
 """
     Folio extension that uses python markdown to parse templates.
+    
+    This extension add a builder that parse text files using markdown_ package
+    and generate a given template with the `content` variable filled with the
+    generated HTML.
+    
+    .. _markdown: https://pypi.python.org/pypi/Markdown/
+    
+    :param MARKDOWN_TEMPLATE: The template to generate with the `content`
+                              variable. Defaults to "_markdown.html".
+    :param MARKDOWN_EXTENSIONS: Extra extensions to be passed to markdown.
+    :param MARKDOWN_BUILDER_PATTERNS: Filename patterns that will be assigned
+                                      to the builder.
 """
 
 from __future__ import with_statement
@@ -8,6 +20,7 @@ from __future__ import with_statement
 import os
 import markdown
 
+
 __all__ = ['MarkdownBuilder']
 
 DEFAULT_TEMPLATE = '_markdown.html'
@@ -58,7 +71,7 @@ class MarkdownBuilder(object):
         return '.'.join([name, 'html'])
 
     def parse(self, filename):
-        """Parse the given filename with markdown and return a touple with the
+        """Parse the given filename with markdown and return a tuple with the
         content HTML.
 
         :param filename: The file to parse."""
